Represents a group of functions, macros, callbacks, or types.
Summary
Types
@type t() :: %ExDoc.DocGroupNode{ description: String.t() | nil, doc: ExDoc.DocAST.t() | nil, docs: [ExDoc.DocNode.t()], title: String.t() | atom() }
Represents a group of functions, macros, callbacks, or types.
@type t() :: %ExDoc.DocGroupNode{ description: String.t() | nil, doc: ExDoc.DocAST.t() | nil, docs: [ExDoc.DocNode.t()], title: String.t() | atom() }