Specifies the custom formatter API.
Summary
Callbacks
A list of options to configure autolinking behaviour.
The callback that must be implemented by formatters.
Functions
Copy assets to the given output folder.
Copies the cover to the given location in the output directory.
Copies the favicon to the given location in the output directory.
Copies the logo to the given location in the output directory.
Callbacks
A list of options to configure autolinking behaviour.
@callback run(ExDoc.Formatter.Config.t(), [ExDoc.ModuleNode.t()], [ ExDoc.ExtraNode.t() | ExDoc.URLNode.t() ]) :: %{entrypoint: String.t(), build: [String.t()]}
The callback that must be implemented by formatters.
It receives the configuration, a list of nodes, and it must return the documentation entrypoint plus a list of files built inside the output folder.
Functions
Copy assets to the given output folder.
Copies the cover to the given location in the output directory.
Copies the favicon to the given location in the output directory.
Copies the logo to the given location in the output directory.